species.data package
====================

Submodules
----------

species.data.btnextgen module
-----------------------------

.. automodule:: species.data.btnextgen
    :members:
    :undoc-members:
    :show-inheritance:

species.data.companions module
------------------------------

.. automodule:: species.data.companions
    :members:
    :undoc-members:
    :show-inheritance:

species.data.database module
----------------------------

.. automodule:: species.data.database
    :members:
    :undoc-members:
    :show-inheritance:

species.data.drift\_phoenix module
----------------------------------

.. automodule:: species.data.drift_phoenix
    :members:
    :undoc-members:
    :show-inheritance:

species.data.filters module
---------------------------

.. automodule:: species.data.filters
    :members:
    :undoc-members:
    :show-inheritance:

species.data.irtf module
------------------------

.. automodule:: species.data.irtf
    :members:
    :undoc-members:
    :show-inheritance:

species.data.leggett module
---------------------------

.. automodule:: species.data.leggett
    :members:
    :undoc-members:
    :show-inheritance:

species.data.queries module
---------------------------

.. automodule:: species.data.queries
    :members:
    :undoc-members:
    :show-inheritance:

species.data.spex module
------------------------

.. automodule:: species.data.spex
    :members:
    :undoc-members:
    :show-inheritance:

species.data.util module
------------------------

.. automodule:: species.data.util
    :members:
    :undoc-members:
    :show-inheritance:

species.data.vega module
------------------------

.. automodule:: species.data.vega
    :members:
    :undoc-members:
    :show-inheritance:

species.data.vlm\_plx module
----------------------------

.. automodule:: species.data.vlm_plx
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: species.data
    :members:
    :undoc-members:
    :show-inheritance:
